==> site-0.22.5.Final.zip: src/main/java/org/jboss/tools/rsp/server/generic/servertype/launch/AbstractGenericJavaLauncher.java <==
/*******************************************************************************
 * Copyright (c) 2018 Red Hat, Inc. Distributed under license by Red Hat, Inc.
 * All rights reserved. This program is made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v20.html
 * 
 * Contributors: Red Hat, Inc.
 ******************************************************************************/
package org.jboss.tools.rsp.server.generic.servertype.launch;

import org.jboss.tools.rsp.eclipse.debug.core.DebugException;
import org.jboss.tools.rsp.eclipse.debug.core.ILaunch;
import org.jboss.tools.rsp.eclipse.debug.core.model.IProcess;
import org.jboss.tools.rsp.eclipse.jdt.launching.IVMInstallRegistry;
import org.jboss.tools.rsp.server.LauncherSingleton;
import org.jboss.tools.rsp.server.spi.launchers.AbstractJavaLauncher;
import org.jboss.tools.rsp.server.spi.launchers.IServerStartLauncher;
import org.jboss.tools.rsp.server.spi.servertype.IServerDelegate;

public abstract class AbstractGenericJavaLauncher extends AbstractJavaLauncher implements IServerStartLauncher {

	public AbstractGenericJavaLauncher(IServerDelegate serverDelegate) {
		super(serverDelegate);
	}

	protected abstract String getWorkingDirectory();

	protected abstract String getMainTypeName();

	protected abstract String getVMArguments();

	protected abstract String getProgramArguments();

	protected abstract String[] getClasspath();

	protected boolean terminateProcesses(ILaunch launch) {
		if( launch == null )
			return false;
		
		IProcess[] all = launch.getProcesses();
		for( int i = 0; i < all.length; i++ ) {
			try {
				all[i].terminate();
			} catch(DebugException de) {
				return false;
			}
		}
		return true;
	}

	@Override
	public IVMInstallRegistry getDefaultRegistry() {
		IVMInstallRegistry registry = null;
		if (LauncherSingleton.getDefault() != null
				&& LauncherSingleton.getDefault().getLauncher() != null
				&& LauncherSingleton.getDefault().getLauncher().getModel() != null) {
					registry = LauncherSingleton.getDefault().getLauncher().getModel().getVMInstallModel();
		}
		return registry;
	}
}

==> site-0.23.9.Final.zip: src/main/java/org/jboss/tools/rsp/server/generic/servertype/launch/AbstractGenericJavaLauncher.java <==
/*******************************************************************************
 * Copyright (c) 2018 Red Hat, Inc. Distributed under license by Red Hat, Inc.
 * All rights reserved. This program is made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v20.html
 * 
 * Contributors: Red Hat, Inc.
 ******************************************************************************/
package org.jboss.tools.rsp.server.generic.servertype.launch;

import org.jboss.tools.rsp.eclipse.debug.core.DebugException;
import org.jboss.tools.rsp.eclipse.debug.core.ILaunch;
import org.jboss.tools.rsp.eclipse.debug.core.model.IProcess;
import org.jboss.tools.rsp.eclipse.jdt.launching.IVMInstall;
import org.jboss.tools.rsp.eclipse.jdt.launching.IVMInstallRegistry;
import org.jboss.tools.rsp.server.LauncherSingleton;
import org.jboss.tools.rsp.server.generic.discovery.GenericVMRegistryDiscovery;
import org.jboss.tools.rsp.server.spi.launchers.AbstractJavaLauncher;
import org.jboss.tools.rsp.server.spi.launchers.IServerStartLauncher;
import org.jboss.tools.rsp.server.spi.servertype.IServerDelegate;

public abstract class AbstractGenericJavaLauncher extends AbstractJavaLauncher implements IServerStartLauncher {

	public AbstractGenericJavaLauncher(IServerDelegate serverDelegate) {
		super(serverDelegate);
	}

	protected abstract String getWorkingDirectory();

	protected abstract String getMainTypeName();

	protected abstract String getVMArguments();

	protected abstract String getProgramArguments();

	protected abstract String[] getClasspath();

	protected boolean terminateProcesses(ILaunch launch) {
		if( launch == null )
			return false;
		
		IProcess[] all = launch.getProcesses();
		for( int i = 0; i < all.length; i++ ) {
			try {
				all[i].terminate();
			} catch(DebugException de) {
				return false;
			}
		}
		return true;
	}

	@Override
	public IVMInstallRegistry getDefaultRegistry() {
		IVMInstallRegistry registry = null;
		if (LauncherSingleton.getDefault() != null
				&& LauncherSingleton.getDefault().getLauncher() != null
				&& LauncherSingleton.getDefault().getLauncher().getModel() != null) {
					registry = LauncherSingleton.getDefault().getLauncher().getModel().getVMInstallModel();
		}
		return registry;
	}
	
	@Override
	protected IVMInstall getVMInstall(IServerDelegate delegate) {
		return new GenericVMRegistryDiscovery().findVMInstall(delegate);
	}
}
